==> xlniuxdata-vipgame-1.0.65-20160616.100243-1-sources.jar: com/xunlei/niux/data/vipgame/vo/business/AgentGames.java <==
package com.xunlei.niux.data.vipgame.vo.business;


import com.ferret.common.dao.annotation.Table;


/**
 * @author lisu
 *  2015-01-08
 */
@Table(tableName = "agentgames", pkFieldName = "seqId", pkFieldAssign = false)
public class AgentGames {
      private Long seqId;
      private String gameId;
      private String gameNo;
      private String gameName;
      private Integer openStatus;
      private String remark;
      private String inputBy;
      private String inputTime;
      private String editBy;
      private String editTime;
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getGameNo() {
		return gameNo;
	}
	public void setGameNo(String gameNo) {
		this.gameNo = gameNo;
	}
	public String getGameName() {
		return gameName;
	}
	public void setGameName(String gameName) {
		this.gameName = gameName;
	}
	public Integer getOpenStatus() {
		return openStatus;
	}
	public void setOpenStatus(Integer openStatus) {
		this.openStatus = openStatus;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
      
      
}

==> xlniuxdata-vipgame-1.0.65-20170106.102118-61-sources.jar: com/xunlei/niux/data/vipgame/vo/business/AgentGames.java <==
package com.xunlei.niux.data.vipgame.vo.business;


import com.ferret.common.dao.annotation.Table;


/**
 * @author lisu
 *  2015-01-08
 */
@Table(tableName = "agentgames", pkFieldName = "seqId", pkFieldAssign = false)
public class AgentGames {
      private Long seqId;
      private String gameId;
      private String gameNo;
      private String gameName;
      private Integer openStatus;
      private String remark;
      private String inputBy;
      private String inputTime;
      private String editBy;
      private String editTime;
      private String queryKey;
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getGameNo() {
		return gameNo;
	}
	public void setGameNo(String gameNo) {
		this.gameNo = gameNo;
	}
	public String getGameName() {
		return gameName;
	}
	public void setGameName(String gameName) {
		this.gameName = gameName;
	}
	public Integer getOpenStatus() {
		return openStatus;
	}
	public void setOpenStatus(Integer openStatus) {
		this.openStatus = openStatus;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public String getQueryKey() {
		return queryKey;
	}
	public void setQueryKey(String queryKey) {
		this.queryKey = queryKey;
	}
      
      
}
